==> geonapi_0.8.zip: geonapi/NEWS.md <==
## [geonapi 0.8](https://github.com/eblondel/geonapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-unavailable-red.svg)](https://github.com/eblondel/geonapi)

**Enhancements**

* [#33](https://github.com/eblondel/geonapi/issues/33) Support ISO 19115-3 standard metadata (with [geometa](https://github.com/eblondel/geometa) version 0.9)

## [geonapi 0.7-2](https://github.com/eblondel/geonapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://github.com/eblondel/geonapi)

**Bug fixes**

* [#31](https://github.com/eblondel/geonapi/issues/31) Empty response for thumbnail publication

## [geonapi 0.7-1](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.7-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.7-1.tar.gz)

**Enhancements**

* [#30](https://github.com/eblondel/geonapi/issues/30) Consolidate getTags with rbind.fill instead of rbind

## [geonapi 0.7](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.7.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.7.tar.gz)


* [#26](https://github.com/eblondel/geonapi/issues/26) Improve error handling for metadata upload

**New features**

* [#29](https://github.com/eblondel/geonapi/issues/29) Add DOI management methods (with DataCite)

## [geonapi 0.6-1](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.6-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.6-1.tar.gz)

**Corrections**

* [#25](https://github.com/eblondel/geonapi/issues/25) Upgrade roxygen2 7.2.1 to fix html issues

## [geonapi 0.6](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.6.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.6.tar.gz)

**New features**

* [#15](https://github.com/eblondel/geonapi/issues/15) Support attachements upload via Open API
* [#23](https://github.com/eblondel/geonapi/issues/23) Support thumbnail publication via Open API 

## [geonapi 0.5-3](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-3.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-3.tar.gz)

**Bug fixes**

* [#21](https://github.com/eblondel/geonapi/issues/21) Regression of login & other methods related to Geonetwork API url

## [geonapi 0.5-2](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-2.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-2.tar.gz)

**New features**

* [#19](https://github.com/eblondel/geonapi/issues/19) Support new parameter for specifying custom INSPIRE metadata validator

**Miscs**

* [#22](https://github.com/eblondel/geonapi/issues/22) Standardize R6-class R documentation

## [geonapi 0.5-1](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-1.tar.gz)

**Bug fixes**

* [#16](https://github.com/eblondel/geonapi/issues/16) Issue with GN login with GN 3.8 - Missing lang in service URL

## [geonapi 0.5](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5.tar.gz)

**New features**

* [#2](https://github.com/eblondel/geonapi/issues/2) Support new Geonetwork REST API (GN >= 3.2) - main CRUD methods
* [#14](https://github.com/eblondel/geonapi/issues/14) Add method to get categories 

**Enhancements**

* [#13](https://github.com/eblondel/geonapi/issues/13) Issue with Keyring >= 1.2.0 - system password requested - Set keyring 'env' backend by default

## [geonapi 0.4](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.4.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.4.tar.gz)

**New features**

* [#10](https://github.com/eblondel/geonapi/issues/10) Secure API password with 'keyring'

## [geonapi 0.3-1](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.3-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.3-1.tar.gz)

* Fix bad code at https://github.com/eblondel/geonapi/commit/2bab0a20d64450a605abc326caa71443dc27d039

## [geonapi 0.3](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.3.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.3.tar.gz)

**Bug fixes**

* [#8](https://github.com/eblondel/geonapi/issues/8) Fix crsf authorization for GN > 3.2

**Miscs**

* [#9](https://github.com/eblondel/geonapi/issues/9) Integration tests on major GN versions


## [geonapi 0.2-2](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-2.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-2.tar.gz)

**Enhancements**

* [#7](https://github.com/eblondel/geonapi/issues/7) propagate geometa validate/inspire options to insert/update methods


## [geonapi 0.2-1](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-1.tar.gz)

**New features**

* [#6](https://github.com/eblondel/geonapi/issues/6) Method to list user groups

**Enhancements**

* [#5](https://github.com/eblondel/geonapi/issues/5) Test insertion / update of multi-lingual metadata records


## [geonapi 0.2-0](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-0.tar.gz)

**New features**

* [#](https://github.com/eblondel/geonapi/issues/4) new http request token requirements (CSRF)

## [geonapi 0.1-0](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.1-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.1-0.tar.gz)

1st version (support for legacy API)

==> geonapi_0.8-1.zip: geonapi/NEWS.md <==
## [geonapi 0.8-1](https://github.com/eblondel/geonapi) |
[![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://github.com/eblondel/geonapi)

**Enhancements**

- [#38](https://github.com/eblondel/geonapi/issues/38) INSPIRE metadata validator does not need API key anymore
- [#39](https://github.com/eblondel/geonapi/issues/39) Support metadata privileges configuration for new API

**New features**

* [#35](https://github.com/eblondel/geonapi/issues/35) Add method to simply download a metadata by Id

## [geonapi 0.8](https://github.com/eblondel/geonapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://github.com/eblondel/geonapi)

**Enhancements**

* [#33](https://github.com/eblondel/geonapi/issues/33) Support ISO 19115-3 standard metadata (with [geometa](https://github.com/eblondel/geometa) version 0.9)

## [geonapi 0.7-2](https://github.com/eblondel/geonapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://github.com/eblondel/geonapi)

**Bug fixes**

* [#31](https://github.com/eblondel/geonapi/issues/31) Empty response for thumbnail publication

## [geonapi 0.7-1](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.7-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.7-1.tar.gz)

**Enhancements**

* [#30](https://github.com/eblondel/geonapi/issues/30) Consolidate getTags with rbind.fill instead of rbind

## [geonapi 0.7](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.7.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.7.tar.gz)


* [#26](https://github.com/eblondel/geonapi/issues/26) Improve error handling for metadata upload

**New features**

* [#29](https://github.com/eblondel/geonapi/issues/29) Add DOI management methods (with DataCite)

## [geonapi 0.6-1](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.6-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.6-1.tar.gz)

**Corrections**

* [#25](https://github.com/eblondel/geonapi/issues/25) Upgrade roxygen2 7.2.1 to fix html issues

## [geonapi 0.6](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.6.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.6.tar.gz)

**New features**

* [#15](https://github.com/eblondel/geonapi/issues/15) Support attachements upload via Open API
* [#23](https://github.com/eblondel/geonapi/issues/23) Support thumbnail publication via Open API 

## [geonapi 0.5-3](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-3.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-3.tar.gz)

**Bug fixes**

* [#21](https://github.com/eblondel/geonapi/issues/21) Regression of login & other methods related to Geonetwork API url

## [geonapi 0.5-2](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-2.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-2.tar.gz)

**New features**

* [#19](https://github.com/eblondel/geonapi/issues/19) Support new parameter for specifying custom INSPIRE metadata validator

**Miscs**

* [#22](https://github.com/eblondel/geonapi/issues/22) Standardize R6-class R documentation

## [geonapi 0.5-1](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5-1.tar.gz)

**Bug fixes**

* [#16](https://github.com/eblondel/geonapi/issues/16) Issue with GN login with GN 3.8 - Missing lang in service URL

## [geonapi 0.5](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.5.tar.gz)

**New features**

* [#2](https://github.com/eblondel/geonapi/issues/2) Support new Geonetwork REST API (GN >= 3.2) - main CRUD methods
* [#14](https://github.com/eblondel/geonapi/issues/14) Add method to get categories 

**Enhancements**

* [#13](https://github.com/eblondel/geonapi/issues/13) Issue with Keyring >= 1.2.0 - system password requested - Set keyring 'env' backend by default

## [geonapi 0.4](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.4.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.4.tar.gz)

**New features**

* [#10](https://github.com/eblondel/geonapi/issues/10) Secure API password with 'keyring'

## [geonapi 0.3-1](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.3-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.3-1.tar.gz)

* Fix bad code at https://github.com/eblondel/geonapi/commit/2bab0a20d64450a605abc326caa71443dc27d039

## [geonapi 0.3](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.3.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.3.tar.gz)

**Bug fixes**

* [#8](https://github.com/eblondel/geonapi/issues/8) Fix crsf authorization for GN > 3.2

**Miscs**

* [#9](https://github.com/eblondel/geonapi/issues/9) Integration tests on major GN versions


## [geonapi 0.2-2](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-2.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-2.tar.gz)

**Enhancements**

* [#7](https://github.com/eblondel/geonapi/issues/7) propagate geometa validate/inspire options to insert/update methods


## [geonapi 0.2-1](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-1.tar.gz)

**New features**

* [#6](https://github.com/eblondel/geonapi/issues/6) Method to list user groups

**Enhancements**

* [#5](https://github.com/eblondel/geonapi/issues/5) Test insertion / update of multi-lingual metadata records


## [geonapi 0.2-0](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.2-0.tar.gz)

**New features**

* [#](https://github.com/eblondel/geonapi/issues/4) new http request token requirements (CSRF)

## [geonapi 0.1-0](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.1-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geonapi/geonapi_0.1-0.tar.gz)

1st version (support for legacy API)
